/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is Robert John Churchill.
 * Portions created by the Initial Developer are Copyright (C) 2002
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): 
 *    Robert John Churchill   <rjc@netscape.com> (Original Author)
 *    Karsten Duesterloh      <kd-moz@tprac.de>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

const ISEARCH_CONTRACTID       = "@mozilla.org/rdf/datasource;1?name=internetsearch";
const RDFSERVICE_CONTRACTID    = "@mozilla.org/rdf/rdf-service;1";
const BMARKS_CONTRACTID        = "@mozilla.org/browser/bookmarks-service;1";

const nsIBookmarksService      = Components.interfaces.nsIBookmarksService;
const nsIRDFService            = Components.interfaces.nsIRDFService;
const nsIRDFLiteral            = Components.interfaces.nsIRDFLiteral;
const nsIRDFDataSource         = Components.interfaces.nsIRDFDataSource;
const nsIRDFRemoteDataSource   = Components.interfaces.nsIRDFRemoteDataSource;
const nsIInternetSearchService = Components.interfaces.nsIInternetSearchService;

var searchDS = Components.classes[ISEARCH_CONTRACTID].getService(nsIInternetSearchService);
var iSearch = Components.classes[ISEARCH_CONTRACTID].getService(nsIInternetSearchService);
var ADSPrefs = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
var ADSPrefs1 = ADSPrefs.getBranch("extensions.advancedsearch.");
var ADSPrefs2 = ADSPrefs.getBranch("browser.search.");
var ADSPrefs3 = ADSPrefs.getBranch("keyword.");

function setSearchMode()
{
  var   searchMode = 0;
  if (pref) searchMode = pref.getIntPref("extensions.advancedsearch.mode");
  if (searchMode == 0)  searchMode = 1;
  else      searchMode = 0;
  if (pref) pref.setIntPref("extensions.advancedsearch.mode", searchMode);
  return(true);
}

/* Note: doSort() does NOT support natural order sorting, unless naturalOrderResource is valid,
         in which case we sort ascending on naturalOrderResource
 */
function doSort(sortColName, naturalOrderResource)
{
  var node = document.getElementById(sortColName);
  // determine column resource to sort on
  var sortResource = node.getAttribute('resource');
  if (!sortResource) return(false);

  var sortDirection="ascending";
  var isSortActive = node.getAttribute('sortActive');
  if (isSortActive == "true")
  {
    sortDirection = "ascending";

    var currentDirection = node.getAttribute('sortDirection');
    if (currentDirection == "ascending")
    {
      if (sortResource != naturalOrderResource)
      {
        sortDirection = "descending";
      }
    }
    else if (currentDirection == "descending")
    {
      if (naturalOrderResource != null && naturalOrderResource != "")
      {
        sortResource = naturalOrderResource;
      }
    }
  }

  var isupports = Components.classes["@mozilla.org/xul/xul-sort-service;1"].getService();
  if (!isupports)    return(false);
  var xulSortService = isupports.QueryInterface(Components.interfaces.nsIXULSortService);
  if (!xulSortService)    return(false);
  try
  {
    xulSortService.sort(node, sortResource, sortDirection);
  }
  catch(ex)
  {
    debug("Exception calling xulSortService.sort()");
  }
  return(true);
}



function setInitialSort(node, sortDirection)
{
  // determine column resource to sort on
  var sortResource = node.getAttribute('resource');
  if (!sortResource) return(false);

  try
  {
    var isupports = Components.classes["@mozilla.org/xul/xul-sort-service;1"].getService();
    if (!isupports)    return(false);
    var xulSortService = isupports.QueryInterface(Components.interfaces.nsIXULSortService);
    if (!xulSortService)    return(false);
    xulSortService.sort(node, sortResource, sortDirection);
  }
  catch(ex)
  {
  }
  return(true);
}


function switchTab(aPageIndex)
{
  var deck = document.getElementById("advancedDeck");
  if (!deck)
  { // get the search-panel deck the hard way 
    // otherwise the switchTab call from internetresults.xul would fail
    //var oSearchPanel = getNavigatorWindow(false).sidebarObj.panels.get_panel_from_id("urn:sidebar:panel:search");
    var oSearchPanel = document.getElementById("sidebar");
	if (!oSearchPanel)
      return;
    deck = oSearchPanel.get_iframe().contentDocument.getElementById("advancedDeck")
  }
  deck.setAttribute("selectedIndex", aPageIndex);
}
// retrieves the most recent navigator window
function getNavigatorWindow(aOpenFlag)
{
  var navigatorWindow;

  // if this is a browser window, just use it
  if ("document" in top) {
    var possibleNavigator = top.document.getElementById("main-window");
    if (possibleNavigator &&
        possibleNavigator.getAttribute("windowtype") == "navigator:browser")
      navigatorWindow = top;
  }

  // if not, get the most recently used browser window
  if (!navigatorWindow) {
    var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                       .getService(Components.interfaces.nsIWindowMediator);
    navigatorWindow = wm.getMostRecentWindow("navigator:browser");
  }

  // if no browser window available and it's ok to open a new one, do so
  if (!navigatorWindow && aOpenFlag) {
    var navigatorChromeURL = search_getBrowserURL();
    navigatorWindow = openDialog(navigatorChromeURL, "_blank", "chrome,all,dialog=no");
  }
  return navigatorWindow;
}

function doNavButtonEnabling(whichButtons, searchService, pageNumber)
{
  var openFromSidebar = ADSPrefs1.getBoolPref('calledfromsidebar');
    
  if (openFromSidebar == true) {
  var nextButton = document.getElementById("next-results");
  var nextDisabled = nextButton.getAttribute("disabled");
  var prevButton = document.getElementById("prev-results");
  var prevDisabled = prevButton.getAttribute("disabled");
  } else {
  var nextButton = top.document.getElementById('sidebar').contentDocument.getElementById("next-results");
  var nextDisabled = nextButton.getAttribute("disabled");
  var prevButton = top.document.getElementById('sidebar').contentDocument.getElementById("prev-results");
  var prevDisabled = prevButton.getAttribute("disabled");
  }
  if (whichButtons && searchService.kHaveNext)
  {
      if (nextDisabled)
      nextButton.removeAttribute("disabled");
  }
  else 
  {
    if (!nextDisabled)
      nextButton.setAttribute("disabled", "true");
  }
  
  if ((pageNumber > 0) && (whichButtons & searchService.kHavePrev))
  {
    if (prevDisabled)
      prevButton.removeAttribute("disabled");
  }
  else 
  {
    if (!prevDisabled)
      prevButton.setAttribute("disabled", "true");
  }
}

function activateButtonsFromAnywhere() {
var ADS3Prefs1 = ADSPrefs1.getBoolPref("calledfromsidebar");
var ADS3Prefs2 = ADSPrefs1.getIntPref("mode");

var st = /(keyword:)([a-zA-Z0-9\s].*)/;
var searchText = String(top._content.location).match(st);

if (searchText) {
url = decodeURI(ADSPrefs3.getCharPref("URL")+searchText[2]); 
} else { 
url = top._content.location;
}

st = /adspage=([0-9])+/
url1 = String(url).match(st);

var pagenumber;

try {
if (url1) {
pagenumber = url1[1];
} else {
pagenumber = 0;
}
} catch (e) {
}

st = /http:\/\/([a-zA-Z0-9\s\/].*)\?/
url = String(url).match(st);

var itemNodeID;

try {
var searchTerm = top.document.getElementById('sidebar').contentDocument.getElementById('sidebar-search-text').value
} catch (e) {
//alert (e);
var searchTerm = document.getElementById('sidebar-search-text').value
}

var whichButtons = new Object;
whichButtons.value = 0;

var searchURL1;

if (ADS3Prefs2 == 0) {
if (ADS3Prefs1 == false) {
var engineBox = top.document.getElementById('sidebar').contentDocument.getElementById("basicEngineMenu");
} else {
var engineBox = document.getElementById("basicEngineMenu");
}
 
try {
var engBox = engineBox.selectedItem.id;
for (var x = 0; x < engineBox.childNodes.item(1).childNodes.length; ++x) {
itemNode = engineBox.childNodes.item(1).childNodes[x];
if (itemNode.localName == "menuitem") {
itemNodeID = String(decodeURI(itemNode.id)).match(st);
st = /(engine:\/\/|engine:)/g;
itemNodeID = String(decodeURI(itemNode.id)).replace(st,"");
st = /(%3A)/g;
itemNodeID = String(itemNodeID).replace(st, ":");
st = /(\/)/g;
itemNodeID = String(itemNodeID).replace(st, "\\");
searchURL1 = iSearch.GetInternetSearchURL("engine://"+encodeURI(itemNodeID), searchTerm, 0, 0, whichButtons);
st = /http:\/\/([a-zA-Z0-9\s\/].*)\?/
searchURL1 = String(searchURL1).match(st);
if (searchURL1[0] == url[0]) {
engineBox.value = itemNode.id;
doNavButtonEnabling(whichButtons.value, iSearch, pagenumber);
}
}
}
} catch (e) {
//alert (e);
}
}

if (ADS3Prefs2 == 1) {
if (ADS3Prefs1 == "false") {
var engineBox = top.document.getElementById('sidebar').contentWindow.document.getElementById("searchengines");
} else {
var engineBox = document.getElementById("searchengines");
}

try { 
for (var x = 0; x < engineBox.childNodes.length; ++x) {
itemNode = engineBox.childNodes[x];
if (itemNode.localName == "listitem") {
st = /([NC:SearchCategory\w].*)/g;
itemNodeID = String(decodeURI(itemNode.id)).match(st);
if (itemNodeID) {
itemNodeID = itemNodeID;
} else {
st = /(engine:\/\/|engine:)/g;
itemNodeID = String(decodeURI(itemNode.id)).replace(st,"");
st = /(%3A)/g;
itemNodeID = String(itemNodeID).replace(st, ":");
st = /(\/)/g;
itemNodeID = String(itemNodeID).replace(st, "\\");
itemNodeID = "engine://"+encodeURI(itemNodeID);
}
searchURL1 = iSearch.GetInternetSearchURL(itemNodeID, searchTerm, 0, 0, whichButtons);
st = /http:\/\/([a-zA-Z0-9\s\/].*)\?/
searchURL1 = String(searchURL1).match(st);
if (searchURL1[0] == url[0] || engineBox.childNodes.length == 3) {
itemNode.checked = true;
doNavButtonEnabling(whichButtons.value, iSearch, pagenumber);
} else {
itemNode.checked = false;
} 
} 
}
} catch (e) {
//alert (e);
}
}
ADSPrefs1.setBoolPref("calledfromsidebar",false);
}

function getFileFromURLSpec(url) {
try {
const nsIFileProtocolHandler = Components.interfaces.nsIFileProtocolHandler;
var handler = Components.classes["@mozilla.org/network/protocol;1?name=file"].createInstance();
handler = handler.QueryInterface(nsIFileProtocolHandler);
return handler.getFileFromURLSpec(url);
} catch (err) {
alert (err);
}
}

function deleteFile(fileName) {
var alertDialog

try {
var stringBundle = srGetStrBundle("chrome://searchsidebar/locale/search-panel.properties");
if (stringBundle) {
alertDialog = stringBundle.GetStringFromName("alreadyRemoved");
} 
} catch (e) {
alertDialog = "already removed. Restart browser to take effect";
}

var file  = Components.classes["@mozilla.org/file/local;1"].createInstance(Components.interfaces.nsILocalFile);
file.initWithPath(fileName);
try {
file.remove(false);
} catch (e) {
alert (fileName+" "+alertDialog);
return;
}
}

function deleteSearchPlugin(listitem) {
var id = listitem.id;
var name = listitem.label;
var pluginFile = unescape(id);
var imageFile  = unescape(listitem.getAttribute('image'));

if (pluginFile.substring(0, 9) == 'engine://') {
pluginFile = pluginFile.substring(9);
} else {
//TBD: print warning
return;
}

if (imageFile.substring(0, 8) != 'file:///') {
//TBD: print warning
return;
}

// convert to native path spec: 
imageFile = getFileFromURLSpec(imageFile).path;

var titleMessage, dialogMessage, errorMessage;

try {
var stringBundle = srGetStrBundle("chrome://searchsidebar/locale/search-panel.properties");
if (stringBundle) {
titleMessage = stringBundle.GetStringFromName("deletePlugin");
dialogMessage = stringBundle.GetStringFromName("doyouWishToDelete");
} 
} catch (e) {
titleMessage = "Delete Search Plugin?";
dialogMessage = "Do you wish to delete";
}

var prompter = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(Components.interfaces.nsIPromptService);
var result = prompter.confirm(window,titleMessage,dialogMessage+" "+name+"?");
if (!result) {
return;
}

deleteFile(pluginFile);
deleteFile(imageFile);
//var deletedId = popupNode.getAttribute('id');
//if (deletedId == popupNode.parentNode.parentNode.parentNode.currentEngine) {
//}

listitem.parentNode.removeChild(listitem);
}

